# Stalemate
A simple, lightweight, python chess graphics engine.

## Installation

Use the pip to install

    pip install Stalemate

## Import

To import Stalemate to use graphics, use this:

    from Stalemate import *
   
This will import everything in the library.

## Documentation

To see how to use stalemate, visit the github [wiki](https://github.com/Quantalabs/Stalemate/wiki).